==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Hatch</name>
    <message>
        <location filename="../Hatch.js" line="+56"/>
        <source>No boundary selected.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">No granica zaznaczona.</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Loop not closed at point %1/%2.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pętla nie zamknięta w punkcie /.</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Każda jednostka musi być granica linia, łuk, okrąg, elipsa, łuk, elipsa, polilinia lub splajn. Znaleziono:</translation>
    </message>
    <message>
        <location filename="../HatchInit.js" line="+2"/>
        <source>&amp;Hatch</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Kreskowanie
Wzory &amp;kreskowania:</translatorcomment>
        <translation type="unfinished">&amp;Kreskowanie</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw hatch or solid fill</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Remis kreskowania lub stałe wypełnienie</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Kreskowanie
&amp;Kreskowanie</translatorcomment>
        <translation type="unfinished">Kreskowanie</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Type</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Typ linii:
Typ linii
Typ</translatorcomment>
        <translation type="unfinished">Typ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Rysuj kreskowanie i jednolite wypełnienia
Kreskowanie / całkowite Wypełnienia</translatorcomment>
        <translation type="unfinished">Wypełnienie jednolite</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translatorcomment>--google--
Wzory kreskowania:
Wzory kreskowania</translatorcomment>
        <translation type="unfinished">Wzór Hatch</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Podgląd wydruku dla %1
Podgląd wydruku
Pokazuje podgląd wydruku</translatorcomment>
        <translation type="unfinished">Podgląd</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wzór
Wzory kreskowania:</translatorcomment>
        <translation type="unfinished">Wzór</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation type="unfinished">Kąt:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Skala:</translatorcomment>
        <translation type="unfinished">Skala:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Hatch</name>
    <message>
        <source>No boundary selected.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">No granica zaznaczona.</translation>
    </message>
    <message>
        <source>Loop not closed at point %1/%2.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Pętla nie zamknięta w punkcie /.</translation>
    </message>
    <message>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Każda jednostka musi być granica linia, łuk, okrąg, elipsa, łuk, elipsa, polilinia lub splajn. Znaleziono:</translation>
    </message>
    <message>
        <location filename="../Hatch.js" line="+72"/>
        <source>Hatch Tools</source>
        <translation>Narzędzia kreskowania</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show hatch tools</source>
        <translation>Wyświetla narzędzia kreskowania</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Hatch</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Kreskowanie
Wzory &amp;kreskowania:</translatorcomment>
        <translation>&amp;Kreskowanie</translation>
    </message>
    <message>
        <source>Draw hatch or solid fill</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Remis kreskowania lub stałe wypełnienie</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Kreskowanie
&amp;Kreskowanie</translatorcomment>
        <translation>Kreskowanie</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Type</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Typ linii:
Typ linii
Typ</translatorcomment>
        <translation>Rodzaj</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Rysuj kreskowanie i jednolite wypełnienia
Kreskowanie / całkowite Wypełnienia</translatorcomment>
        <translation>Jednolite wypełnienie</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translatorcomment>--google--
Wzory kreskowania:
Wzory kreskowania</translatorcomment>
        <translation>Wzór kreskowania</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Podgląd wydruku dla %1
Podgląd wydruku
Pokazuje podgląd wydruku</translatorcomment>
        <translation>Podgląd</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wzór
Wzory kreskowania:</translatorcomment>
        <translation>Wzór</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation>Kąt:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Skala:</translatorcomment>
        <translation>Skala:</translation>
    </message>
</context>
</TS>
